@@ -71,7 +71,7 @@ test_that("Old API works", {
 
   invisible(get_flu_data())
 
-  invisible(get_hosp_data())
+  invisible(get_hosp_data(years = 2019))
 
   invisible(get_flu_data(data_source="all"))
 
